jQuery( document ).ready( function ( $ ) {
    "use strict";
    
    $.fn.yith_wcbk_timepicker = function ( options ) {
        var defaults = {
                id: 'yith-wcbk-timepicker',
                class: 'yith-wcbk-timepicker',
                input_class: 'yith-wcbk-timepicker-input'
            },
            timepicker;


        self.opts = $.extend( {}, defaults, options );

        //create timepicker if not exists
        var create      = function () {
                if ( $( document ).find( '#' + self.opts.id ).length > 0 ) {
                    timepicker = $( document ).find( '#' + self.opts.id );
                } else {
                    timepicker = $( '<div id="' + self.opts.id + '" />' ).addClass( self.opts.class );

                    var h_options = '',
                        m_options = '';
                    for ( var i = 0; i < 24; i++ ) {
                        var h_n = i < 10 ? '0' + i : i;
                        h_options += '<option value=' + h_n + '>' + h_n + '</option>';
                    }
                    for ( var j = 0; j < 60; j++ ) {
                        var m_n = j < 10 ? '0' + j : j;
                        m_options += '<option value=' + m_n + '>' + m_n + '</option>';
                    }

                    var table = '<table>' +
                        '<tr>' +
                        '<td><span class="dashicons dashicons-arrow-up-alt2 ' + self.opts.class + '-arrow-up ' + self.opts.class + '-arrow-up-hours"></span></td>' +
                        '<td></td>' +
                        '<td><span class="dashicons dashicons-arrow-up-alt2 ' + self.opts.class + '-arrow-up ' + self.opts.class + '-arrow-up-minutes"></span></td>' +
                        '</tr>' +
                        '<tr>' +
                        '<td>' +
                        '<select class="' + self.opts.class + '-hours">' +
                        h_options +
                        '</select>' +
                        '</td>' +
                        '<td>:</td>' +
                        '<td>' +
                        '<select class="' + self.opts.class + '-minutes">' +
                        m_options +
                        '</select></td>' +
                        '</tr>' +
                        '<tr>' +
                        '<td><span class="dashicons dashicons-arrow-down-alt2 ' + self.opts.class + '-arrow-down ' + self.opts.class + '-arrow-down-hours"></span></td>' +
                        '<td></td>' +
                        '<td><span class="dashicons dashicons-arrow-down-alt2 ' + self.opts.class + '-arrow-down ' + self.opts.class + '-arrow-down-minutes"></span></td>' +
                        '</tr>' +
                        '</table>';

                    timepicker.html( table );

                    $( document.body ).append( timepicker );
                    timepicker.hide();

                    add_actions();
                }
            },
            add_actions = function () {
                timepicker.on( 'click', function ( event ) {
                    event.stopPropagation();
                    var $target = $( event.target ),
                        hours   = $( this ).find( '.' + self.opts.class + '-hours' ),
                        minutes = $( this ).find( '.' + self.opts.class + '-minutes' );

                    if ( $target.is( '.' + self.opts.class + '-arrow-up-hours' ) ) {
                        var index = parseInt( hours.val() );
                        if ( index >= 23 )
                            index = -1;
                        hours.prop( 'selectedIndex', index + 1 );
                        $( this ).trigger( 'time_change' );
                    }
                    if ( $target.is( '.' + self.opts.class + '-arrow-down-hours' ) ) {
                        var index = parseInt( hours.val() );
                        if ( index <= 0 )
                            index = 24;
                        hours.prop( 'selectedIndex', index - 1 );
                        $( this ).trigger( 'time_change' );
                    }

                    if ( $target.is( '.' + self.opts.class + '-arrow-up-minutes' ) ) {
                        var index = parseInt( minutes.val() );
                        if ( index >= 59 )
                            index = -1;
                        minutes.prop( 'selectedIndex', index + 1 );
                        $( this ).trigger( 'time_change' );
                    }
                    if ( $target.is( '.' + self.opts.class + '-arrow-down-minutes' ) ) {
                        var index = parseInt( minutes.val() );
                        if ( index <= 0 )
                            index = 60;
                        minutes.prop( 'selectedIndex', index - 1 );
                        $( this ).trigger( 'time_change' );
                    }
                } )
                    .on( 'change', '.' + self.opts.class + '-hours, .' + self.opts.class + '-minutes', function ( event ) {
                        $( this ).trigger( 'time_change' );
                    } )

                    .on( 'time_change', function ( event ) {
                        var input   = $( this ).parent().find( 'input' ),
                            hours   = $( this ).find( '.' + self.opts.class + '-hours' ),
                            minutes = $( this ).find( '.' + self.opts.class + '-minutes' );
                        input.val( hours.val() + ':' + minutes.val() );
                    } );

                $( document ).on( 'click', '.' + self.opts.input_class, function ( event ) {
                        event.stopPropagation();
                        var $target = $( event.target ),
                            val     = $target.val(),
                            time    = val.split( ':' );

                        if ( time.length == 2 ) {
                            var h = parseInt( time[ 0 ] ),
                                m = parseInt( time[ 1 ] );

                            timepicker.find( '.' + self.opts.class + '-hours' ).prop( 'selectedIndex', h );
                            timepicker.find( '.' + self.opts.class + '-minutes' ).prop( 'selectedIndex', m );
                        } else {
                            timepicker.find( '.' + self.opts.class + '-hours' ).prop( 'selectedIndex', 0 );
                            timepicker.find( '.' + self.opts.class + '-minutes' ).prop( 'selectedIndex', 0 );
                        }

                        timepicker.appendTo( $target.parent() ).css( {
                            position: 'absolute',
                            top: -timepicker.outerHeight() - 10
                        } );

                        timepicker.show();
                    }
                )

                    .on( 'click', function ( event ) {
                        timepicker.hide();
                    } );
            };

        create();

        return $( this ).each( function ( index, obj ) {
            var wrapper = $( '<div class="' + self.opts.class + '-wrapper" />' ).css( {
                position: 'relative'
            } );
            $( obj ).addClass( self.opts.input_class )
                .attr( 'pattern', '([01]?[0-9]|2[0-3])(:[0-5][0-9])' )
                .attr( 'placeholder', 'hh:mm' )
                .wrap( wrapper );
        } );
    }
} );