<?php
/**
 * Booking Admin Metabox
 *
 * @author  Yithemes
 * @package YITH Booking for WooCommerce Premium
 * @version 1.0.0
 */


if ( !defined( 'YITH_WCBK' ) ) {
    exit;
} // Exit if accessed directly

if ( !class_exists( 'YITH_WCBK_Booking_Metabox' ) ) {
    /**
     * YITH_WCBK_Booking_Metabox
     *
     * @since 1.0.0
     */
    class YITH_WCBK_Booking_Metabox {

        /**
         * Post Type
         *
         * @public string
         */
        public $booking_post_type;

        /**
         * Single instance of the class
         *
         * @var \YITH_WCBK_Product_Form_Helper
         * @since 1.0.0
         */
        protected static $_instance;

        /**
         * Returns single instance of the class
         *
         * @return \YITH_WCBK_Product_Form_Helper
         * @since 1.0.0
         */
        public static function get_instance() {
            if ( is_null( self::$_instance ) ) {
                self::$_instance = new self();
            }

            return self::$_instance;
        }

        /**
         * The constructor
         *
         * @since 1.0.0
         */
        private function __construct() {
            $this->booking_post_type = YITH_WCBK_Post_Types::$booking;

            // remove standard metabox
            add_action( 'admin_menu', array( $this, 'remove_publish_box' ) );
            // add meta
            add_action( 'add_meta_boxes', array( $this, 'add_meta_boxes' ) );
            // save meta
            add_action( 'save_post', array( $this, 'save_booking' ), 10, 1 );
        }

        /**
         * Remove publish box from edit booking
         *
         * @access public
         * @return void
         * @since  1.0.0
         */
        public function remove_publish_box() {
            remove_meta_box( 'submitdiv', $this->booking_post_type, 'side' );
        }

        /**
         * Add meta boxes to edit booking page
         *
         * @access public
         *
         * @param string $post_type Post type.
         *
         * @since  1.0.0
         */
        public function add_meta_boxes( $post_type ) {

            if ( $post_type !== $this->booking_post_type ) {
                return;
            }

            $metaboxes = $this->_get_metaboxes();

            if ( empty( $metaboxes ) || !is_array( $metaboxes ) ) {
                return;
            }

            foreach ( $metaboxes as $metabox ) {
                add_meta_box( $metabox[ 'id' ], $metabox[ 'title' ], array(
                    $this,
                    'meta_box_print',
                ), $this->booking_post_type, $metabox[ 'context' ], $metabox[ 'priority' ] );
            }
        }

        /**
         * Init Meta
         *
         * @access protected
         * @return mixed
         * @since  1.0.0
         * @author Francesco Licandro
         */
        protected function _get_metaboxes() {

            $metaboxes = array(
                10 => array(
                    'id'       => 'yith-booking-notes',
                    'title'    => __( 'Booking notes', 'yith-booking-for-woocommerce' ),
                    'context'  => 'side',
                    'priority' => 'default',
                ),
                20 => array(
                    'id'       => 'yith-booking-actions',
                    'title'    => __( 'Booking actions', 'yith-booking-for-woocommerce' ),
                    'context'  => 'side',
                    'priority' => 'high',
                ),
                30 => array(
                    'id'       => 'yith-booking-data',
                    'title'    => __( 'Booking data', 'yith-booking-for-woocommerce' ),
                    'context'  => 'normal',
                    'priority' => 'high',
                ),
            );

            return apply_filters( 'yith_wcbk_booking_metaboxes_array', $metaboxes );
        }

        /**
         * Print metaboxes content
         *
         * @access public
         * @since  1.0.0
         *
         * @param WP_Post $post Post object.
         * @param array   $metabox
         *
         * @author Francesco Licandro
         */
        public function meta_box_print( $post, $metabox ) {

            if ( !isset( $metabox[ 'id' ] ) ) {
                return;
            }

            switch ( $metabox[ 'id' ] ) {
                case 'yith-booking-notes':
                    $booking = yith_get_booking( $post->ID );
                    $notes   = $booking->get_notes();
                    include( 'html/html-booking-meta-notes.php' );
                    break;
                case 'yith-booking-actions':
                    $booking = yith_get_booking( $post->ID );
                    include( 'html/html-booking-meta-actions.php' );
                    break;
                case 'yith-booking-data':
                    $booking = yith_get_booking( $post->ID );
                    include( 'html/html-booking-meta-data.php' );
                    break;
                default :
                    do_action( 'yith_wcbk_booking_' . $metabox[ 'id' ] . '_print', $post );
                    break;
            }
        }

        /**
         * Save meta on save post
         *
         * @access public
         * @since  1.0.0
         * @author Leanza Francesco <leanzafrancesco@gmail.com>
         *
         * @param int $post_id
         */
        public function save_booking( $post_id ) {
            global $wpdb;
            $booking = yith_get_booking( $post_id );
            if ( $booking ) {
                // CREATION DATE
                if ( isset( $_POST[ 'yith_booking_date' ] ) && isset( $_POST[ 'yith_booking_date_hour' ] ) && isset( $_POST[ 'yith_booking_date_minute' ] ) ) {
                    $post_date = strtotime( $_POST[ 'yith_booking_date' ] . ' ' . (int) $_POST[ 'yith_booking_date_hour' ] . ':' . (int) $_POST[ 'yith_booking_date_minute' ] . ':00' );
                    $post_date = date_i18n( 'Y-m-d H:i:s', $post_date );

                    $wpdb->query( $wpdb->prepare( "UPDATE $wpdb->posts SET post_date = %s, post_date_gmt = %s WHERE ID = %s", $post_date, get_gmt_from_date( $post_date ), $post_id ) );
                }

                // STATUS
                if ( isset( $_POST[ 'yith_booking_status' ] ) ) {
                    $status = $_POST[ 'yith_booking_status' ];
                    $booking->update_status( $status );
                }

                // ORDER
                if ( isset( $_POST[ 'yith_booking_order' ] ) ) {
                    $order_id = absint( $_POST[ 'yith_booking_order' ] );
                    $booking->set( 'order_id', $order_id );
                }

                // USER
                if ( isset( $_POST[ 'yith_booking_user' ] ) ) {
                    $user_id = absint( $_POST[ 'yith_booking_user' ] );
                    $booking->set( 'user_id', $user_id );
                }

                // DATE
                if ( isset( $_POST[ 'yith_booking_from' ] ) ) {
                    $from = strtotime( $_POST[ 'yith_booking_from' ] );
                    $booking->set( 'from', $from );
                }
                if ( isset( $_POST[ 'yith_booking_to' ] ) ) {
                    $to = strtotime( $_POST[ 'yith_booking_to' ] );
                    $booking->set( 'to', $to );
                }
                if ( isset( $_POST[ 'yith_booking_from' ] ) || isset( $_POST[ 'yith_booking_to' ] ) ) {
                    $date_helper = YITH_WCBK_Date_Helper();
                    // calculate duration
                    $duration = $date_helper->get_time_diff( $booking->from, $booking->to, $booking->duration_unit );
                    $booking->set( 'duration', $duration );
                }

                // PERSONS
                if ( $booking->has_person_types() ) {
                    if ( !empty( $_POST[ 'yith_booking_person_type' ] ) ) {
                        $person_types      = $booking->person_types;
                        $post_person_types = $_POST[ 'yith_booking_person_type' ];

                        $total_persons = 0;

                        foreach ( $person_types as $key => $person_type ) {
                            $person_type_id = $person_type[ 'id' ];
                            if ( isset( $post_person_types[ $person_type_id ] ) ) {
                                $person_types[ $key ][ 'number' ] = absint( $post_person_types[ $person_type_id ] );
                            }

                            $total_persons += $person_type[ 'number' ];
                        }
                        $booking->set( 'person_types', $person_types );
                        $booking->set( 'persons', $total_persons );
                    }
                } else {
                    if ( isset( $_POST[ 'yith_booking_persons' ] ) ) {
                        $persons = absint( $_POST[ 'yith_booking_persons' ] );
                        $booking->set( 'persons', $persons );
                    }
                }

            }
        }
    }
}

return YITH_WCBK_Booking_Metabox::get_instance();