<?php
/**
 * Main Booking Admin Class
 *
 * @author  Yithemes
 * @package YITH Booking for WooCommerce Premium
 * @version 1.0.0
 */


if ( !defined( 'YITH_WCBK' ) ) {
    exit;
} // Exit if accessed directly

if ( !class_exists( 'YITH_WCBK_Booking_Admin' ) ) {
    /**
     * YITH_WCBK_Booking_Admin
     *
     * @since 1.0.0
     */
    class YITH_WCBK_Booking_Admin {

        /**
         * Single instance of the class
         *
         * @var \YITH_WCBK_Booking_Admin
         * @since 1.0.0
         */
        protected static $_instance;

        /**
         * @var YITH_WCBK_Booking_Calendar
         */
        public $calendar;

        /**
         * @var YITH_WCBK_Booking_Post_Type_Helper
         */
        public $booking_post_type_helper;

        /**
         * @var YITH_WCBK_Booking_Create
         */
        public $booking_create;

        /**
         * @var YITH_WCBK_Booking_Metabox
         */
        public $booking_metabox;

        /**
         * Returns single instance of the class
         *
         * @return \YITH_WCBK_Admin
         * @since 1.0.0
         */
        public static function get_instance() {
            if ( is_null( self::$_instance ) ) {
                self::$_instance = new self();
            }

            return self::$_instance;
        }

        /**
         * The constructor
         *
         * @since  1.0.0
         * @author Leanza Francesco <leanzafrancesco@gmail.com>
         */
        public function __construct() {
            // Includes handlers file
            $this->_include_files();

            add_action( 'admin_menu', array( $this, 'customize_admin_booking_menu' ), 20 );
        }


        /**
         * Includes handlers file
         *
         * @access protected
         * @since  1.0.0
         */
        protected function _include_files() {
            $this->booking_metabox          = include( 'admin/class.yith-wcbk-booking-metabox.php' );
            $this->booking_create           = include( 'admin/class.yith-wcbk-booking-create.php' );
            $this->calendar                 = include( 'admin/class.yith-wcbk-booking-calendar.php' );
            $this->booking_post_type_helper = include( 'admin/class.yith-wcbk-booking-post-type-helper.php' );
        }

        /**
         * Customize the default booking admin menu ( remove add booking and add more submenu )
         *
         * @access public
         * @since  1.0.0
         */
        public function customize_admin_booking_menu() {
            $booking_menu            = 'edit.php?post_type=' . YITH_WCBK_Post_Types::$booking;
            $add_new_booking_submenu = 'post-new.php?post_type=' . YITH_WCBK_Post_Types::$booking;
            remove_submenu_page( $booking_menu, $add_new_booking_submenu );

            $this->_add_booking_info_bubble_in_menu();
        }

        /**
         * ADD booking info bubble in menu
         * for booking in status pending-confirm or unpaid
         */
        private function _add_booking_info_bubble_in_menu() {
            global $menu;
            $booking_menu     = 'edit.php?post_type=' . YITH_WCBK_Post_Types::$booking;
            $statuses_to_show = array(
                'pending-confirm',
                'unpaid'
            );

            $booking_counts = (array)wp_count_posts( YITH_WCBK_Post_Types::$booking );

            $booking_counters = '';
            foreach ( $statuses_to_show as $status ) {
                $current_counter = isset( $booking_counts[ 'bk-' . $status ] ) ? absint( $booking_counts[ 'bk-' . $status ] ) : 0;
                if ( $current_counter )
                    $booking_counters .= "<span class='yith-wcbk-booking-menu-bubble {$status}'>{$current_counter}</span>";
            }

            foreach ( $menu as $i => $item ) {
                if ( $booking_menu == $item[ 2 ] ) {
                    $menu[ $i ][ 0 ] .= $booking_counters;
                    break;
                }
            }
        }
    }
}

/**
 * Unique access to instance of YITH_WCBK_Admin class
 *
 * @return \YITH_WCBK_Admin
 * @since 1.0.0
 */
function YITH_WCBK_Booking_Admin() {

    return YITH_WCBK_Booking_Admin::get_instance();
}