<?php
/**
 * Admin Assets class
 *
 * @author  Yithemes
 * @package YITH Booking for WooCommerce Premium
 * @version 1.0.0
 */

if ( !defined( 'YITH_WCBK' ) ) {
    exit;
} // Exit if accessed directly

if ( !class_exists( 'YITH_WCBK_Admin_Assets' ) ) {
    /**
     * Admin Assets class.
     * Register and enqueue styles and scripts in Admin
     *
     * @since    1.0.0
     * @author   Leanza Francesco <leanzafrancesco@gmail.com>
     */
    class YITH_WCBK_Admin_Assets {

        /**
         * Single instance of the class
         *
         * @var \YITH_WCBK_Admin_Assets
         * @since 1.0.0
         */
        protected static $_instance;

        /**
         * Returns single instance of the class
         *
         * @return \YITH_WCBK_Admin
         * @since 1.0.0
         */
        public static function get_instance() {
            if ( is_null( self::$_instance ) ) {
                self::$_instance = new self();
            }

            return self::$_instance;
        }

        /**
         * Constructor
         *
         * @access protected
         * @since  1.0.0
         */
        protected function __construct() {
            add_action( 'admin_enqueue_scripts', array( $this, 'admin_styles' ) );
            add_action( 'admin_enqueue_scripts', array( $this, 'admin_scripts' ) );

            add_filter( 'woocommerce_screen_ids', array( $this, 'add_screen_ids' ), 99, 1 );
        }

        public function admin_styles() {
            global $wp_scripts;

            wp_register_style( 'yith-wcbk-timepicker-style', YITH_WCBK_ASSETS_URL . '/css/timepicker.css', YITH_WCBK_VERSION );
            wp_register_style( 'yith-wcbk-admin-style', YITH_WCBK_ASSETS_URL . '/css/admin.css', YITH_WCBK_VERSION );
            wp_register_style( 'yith-wcbk-admin-integrations', YITH_WCBK_ASSETS_URL . '/css/admin-integrations.css', YITH_WCBK_VERSION );
            wp_register_style( 'yith-wcbk-datepicker', YITH_WCBK_ASSETS_URL . '/css/datepicker.css', YITH_WCBK_VERSION );


            $jquery_version = isset( $wp_scripts->registered[ 'jquery-ui-core' ]->ver ) ? $wp_scripts->registered[ 'jquery-ui-core' ]->ver : '1.9.2';
            wp_enqueue_style( 'jquery-ui-style', '//ajax.googleapis.com/ajax/libs/jqueryui/' . $jquery_version . '/themes/smoothness/jquery-ui.css' );

            wp_enqueue_style( 'yith-wcbk-admin-style' );

            if ( $this->is( yith_wcbk_booking_admin_screen_ids() ) || $this->is( 'settings' ) ) {
                wp_enqueue_style( 'yith-wcbk-timepicker-style' );
                wp_enqueue_style( 'yith-wcbk-datepicker' );
            }

            if ( $this->is( 'yith_booking_page_yith-wcbk-booking-calendar' ) ) {
                wp_enqueue_style( 'yith-wcbk-admin-booking-calendar-style', YITH_WCBK_ASSETS_URL . '/css/admin-booking-calendar.css', YITH_WCBK_VERSION );
            }

            if ( $this->is( YITH_WCBK_Post_Types::$booking ) ) {
                wp_enqueue_style( 'yith-wcbk-admin-booking-data-style', YITH_WCBK_ASSETS_URL . '/css/admin-booking-data.css', YITH_WCBK_VERSION );
            }

            if ( $this->is( 'edit-' . YITH_WCBK_Post_Types::$service_tax ) ) {
                wp_register_style( 'yith-wcbk-service-taxonomy-style', YITH_WCBK_ASSETS_URL . '/css/service-taxonomy.css', YITH_WCBK_VERSION );
                wp_enqueue_style( 'yith-wcbk-service-taxonomy-style' );
            }

            if ( $this->is( YITH_WCBK_Post_Types::$search_form ) ) {
                wp_enqueue_style( 'yith-wcbk-admin-booking-search-form', YITH_WCBK_ASSETS_URL . '/css/admin-booking-search-form.css', YITH_WCBK_VERSION );
            }

            if ( $this->is( 'settings', 'integrations' ) ) {
                wp_enqueue_style( 'yith-wcbk-admin-integrations' );

            }
        }

        public function admin_scripts() {
            $suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

            $wcbk_admin = array(
                'prod_type' => YITH_WCBK_Product_Helper::$prod_type,
            );

            $wc_suffix = version_compare( WC()->version, '3.0.0', '>=' ) ? '-wc3' : '';

            // --------------------------------
            // R E G I S T E R   S C R I P T S

            wp_register_script( 'yith-wcbk-timepicker', YITH_WCBK_ASSETS_URL . '/js/timepicker' . $suffix . '.js', array( 'jquery' ), YITH_WCBK_VERSION, true );

            wp_register_script( 'yith-wcbk-admin', YITH_WCBK_ASSETS_URL . '/js/admin/admin' . $suffix . '.js', array( 'jquery', 'yith-wcbk-timepicker' ), YITH_WCBK_VERSION, true );

            wp_register_script( 'yith-wcbk-admin-settings', YITH_WCBK_ASSETS_URL . '/js/admin/admin-settings' . $suffix . '.js', array( 'jquery' ), YITH_WCBK_VERSION, true );

            wp_register_script( 'yith-wcbk-admin-booking-availability-table', YITH_WCBK_ASSETS_URL . '/js/admin/admin-booking-availability-table' . $suffix . '.js', array( 'jquery', 'jquery-ui-datepicker', 'yith-wcbk-timepicker' ), YITH_WCBK_VERSION, true );
            wp_register_script( 'yith-wcbk-admin-booking-bulk-actions', YITH_WCBK_ASSETS_URL . '/js/admin/admin-booking-bulk-actions' . $suffix . '.js', array( 'jquery' ), YITH_WCBK_VERSION, true );
            wp_register_script( 'yith-wcbk-admin-booking-costs-table', YITH_WCBK_ASSETS_URL . '/js/admin/admin-booking-costs-table' . $suffix . '.js', array( 'jquery', 'jquery-ui-datepicker', 'yith-wcbk-timepicker' ), YITH_WCBK_VERSION, true );
            wp_register_script( 'yith-wcbk-admin-booking-calendar', YITH_WCBK_ASSETS_URL . '/js/admin/admin-booking-calendar' . $suffix . '.js', array( 'jquery', ), YITH_WCBK_VERSION, true );
            wp_register_script( 'yith-wcbk-admin-booking-create', YITH_WCBK_ASSETS_URL . '/js/admin/admin-booking-create' . $suffix . '.js', array( 'jquery' ), YITH_WCBK_VERSION, true );
            wp_register_script( 'yith-wcbk-admin-booking-edit-services', YITH_WCBK_ASSETS_URL . '/js/admin/admin-booking-edit-services' . $suffix . '.js', array( 'jquery' ), YITH_WCBK_VERSION, true );
            wp_register_script( 'yith-wcbk-admin-booking-product', YITH_WCBK_ASSETS_URL . '/js/admin/admin-booking-product' . $suffix . '.js', array( 'jquery', 'google-maps', 'yith-wcbk-timepicker' ), YITH_WCBK_VERSION, true );
            wp_register_script( 'yith-wcbk-admin-booking-search-form', YITH_WCBK_ASSETS_URL . '/js/admin/admin-booking-search-form' . $suffix . '.js', array( 'jquery' ), YITH_WCBK_VERSION, true );
            wp_register_script( 'yith-wcbk-admin-booking-utils', YITH_WCBK_ASSETS_URL . '/js/admin/admin-booking-utils' . $suffix . '.js', array( 'jquery', 'jquery-ui-datepicker', 'jquery-tiptip' ), YITH_WCBK_VERSION, true );

            wp_register_script( 'yith-wcbk-enhanced-select', YITH_WCBK_ASSETS_URL . '/js/enhanced-select' . $wc_suffix . $suffix . '.js', array( 'jquery' ), YITH_WCBK_VERSION, true );

            $google_maps_key = get_option( 'yith-wcbk-google-maps-api-key', '' );
            $google_maps_key = !!$google_maps_key ? "&key=$google_maps_key" : '';
            wp_register_script( 'google-maps', "//maps.google.com/maps/api/js?libraries=places$google_maps_key", false, '3' );


            // --------------------------------
            // L O C A L I Z E   S C R I P T S

            wp_localize_script( 'yith-wcbk-admin', 'wcbk_admin', $wcbk_admin );
            wp_localize_script( 'yith-wcbk-admin-booking-product', 'wcbk_admin', $wcbk_admin );
            wp_localize_script( 'yith-wcbk-enhanced-select', 'yith_wcbk_enhanced_select_params', array(
                'ajax_url'              => admin_url( 'admin-ajax.php' ),
                'search_bookings_nonce' => wp_create_nonce( 'search-bookings' ),
                'search_orders_nonce'   => wp_create_nonce( 'search-orders' ),
            ) );

            wp_localize_script( 'yith-wcbk-admin-booking-bulk-actions', 'wcbk_bulk_actions', array(
                'actions' => apply_filters( 'yith_wcbk_booking_bulk_actions', array(
                    'export_to_csv' => __( 'Export to CSV', 'yith-booking-for-woocommerce' ),
                ) ),
            ) );

            // --------------------------------
            // E N Q U E U E   S C R I P T S

            // Booking adming screen ids and Settings Panels
            if ( $this->is( yith_wcbk_booking_admin_screen_ids() ) || $this->is( 'settings' ) ) {
                wp_enqueue_script( 'jquery-tiptip' );
                wp_enqueue_script( 'jquery-ui-datepicker' );

                wp_enqueue_script( 'yith-wcbk-timepicker' );

                wp_enqueue_script( 'yith-wcbk-admin' );

                wp_enqueue_script( 'yith-wcbk-admin-booking-utils' );
                wp_enqueue_script( 'yith-wcbk-enhanced-select' );
            }

            // Settings Panel
            if ( $this->is( 'settings' ) ) {
                wp_enqueue_script( 'yith-wcbk-admin-settings' );

            }

            // Edit Product
            if ( $this->is( 'product' ) ) {
                wp_enqueue_script( 'google-maps' );
                wp_enqueue_script( 'yith-wcbk-admin-booking-availability-table' );
                wp_enqueue_script( 'yith-wcbk-admin-booking-product' );
            }

            // Settings Availability Tab
            if ( $this->is( 'settings', 'availability' ) ) {
                wp_enqueue_script( 'yith-wcbk-admin-booking-availability-table' );
            }

            // Settings Costs Tab
            if ( $this->is( 'settings', 'costs' ) ) {
                wp_enqueue_script( 'yith-wcbk-admin-booking-costs-table' );
            }

            // Calendar
            if ( $this->is( 'yith_booking_page_yith-wcbk-booking-calendar' ) ) {
                wp_enqueue_script( 'yith-wcbk-admin-booking-calendar' );
            }

            // Booking Create
            if ( $this->is( YITH_WCBK_Booking_Create::$screen_id ) ) {
                wp_enqueue_script( 'yith-wcbk-admin-booking-create' );
            }

            // Edit Booking Services
            if ( $this->is( 'edit-' . YITH_WCBK_Post_Types::$service_tax ) ) {
                wp_enqueue_script( 'yith-wcbk-admin-booking-edit-services' );
            }

            // Search Form Post Type
            if ( $this->is( YITH_WCBK_Post_Types::$search_form ) ) {
                wp_enqueue_script( 'yith-wcbk-admin-booking-search-form' );
            }

            // Booking WP List
            if ( $this->is( 'edit-' . YITH_WCBK_Post_Types::$booking ) ) {
                wp_enqueue_script( 'yith-wcbk-admin-booking-bulk-actions' );
            }

        }

        /**
         * Add custom screen ids to standard WC
         *
         * @access public
         *
         * @param array $screen_ids
         *
         * @return array
         * @since  1.0.0
         * @author Leanza Francesco <leanzafrancesco@gmail.com>
         */
        public function add_screen_ids( $screen_ids ) {
            $screen_ids[] = 'yith_booking_page_yith-wcbk-booking-calendar';
            $screen_ids[] = YITH_WCBK_Booking_Create::$screen_id;
            $screen_ids[] = YITH_WCBK_Post_Types::$booking;
            $screen_ids[] = 'edit-' . YITH_WCBK_Post_Types::$service_tax;

            return $screen_ids;
        }

        /**
         * @param array|string $id
         * @param string       $arg
         *
         * @return bool
         */
        public function is( $id, $arg = '' ) {
            $panel_page = 'yith_wcbk_panel';
            $screen     = get_current_screen();

            switch ( $id ) {
                case 'settings':
                    if ( strpos( $screen->id, 'page_' . $panel_page ) > 0 ) {
                        if ( !!$arg ) {
                            return isset( $_GET[ 'tab' ] ) && $_GET[ 'tab' ] === $arg;
                        }

                        return true;
                    }

                    return false;
                    break;
                default:
                    if ( is_array( $id ) ) {
                        return in_array( $screen->id, $id );
                    } elseif ( $id === $screen->id ) {
                        return true;
                    }
                    break;
            }

            return false;
        }
    }
}