<?php
/**
 * Admin class
 *
 * @author  Yithemes
 * @package YITH Booking for WooCommerce Premium
 * @version 1.0.0
 */

if ( !defined( 'YITH_WCBK' ) ) {
    exit;
} // Exit if accessed directly

if ( !class_exists( 'YITH_WCBK_Admin' ) ) {
    /**
     * Admin class.
     * The class manage all the admin behaviors.
     *
     * @since    1.0.0
     * @author   Leanza Francesco <leanzafrancesco@gmail.com>
     * @author   Francesco Licandro
     */
    class YITH_WCBK_Admin {

        /**
         * Single instance of the class
         *
         * @var \YITH_WCBK_Admin
         * @since 1.0.0
         */
        protected static $_instance;

        /**
         * @var $_panel Panel Object
         */
        protected $_panel;

        /**
         * @var string panel page
         */
        protected $_panel_page = 'yith_wcbk_panel';

        /**
         * Various links
         *
         * @var string
         * @access public
         * @since  1.0.0
         */
        public $doc_url = 'http://yithemes.com/docs-plugins/yith-woocommerce-booking/';

        /**
         * Returns single instance of the class
         *
         * @return \YITH_WCBK_Admin
         * @since 1.0.0
         */
        public static function get_instance() {
            if ( is_null( self::$_instance ) ) {
                self::$_instance = new self();
            }

            return self::$_instance;
        }

        /**
         * Constructor
         *
         * @access public
         * @since  1.0.0
         */
        public function __construct() {

            add_action( 'admin_menu', array( $this, 'register_panel' ), 5 );

            // Settings Custom Tab
            add_action( 'yith_wcbk_print_global_availability_tab', array( $this, 'print_global_availability_tab' ) );
            add_action( 'yith_wcbk_print_global_costs_tab', array( $this, 'print_global_costs_tab' ) );
            add_action( 'yith_wcbk_print_integrations_tab', array( $this, 'print_integrations_tab' ) );

            //Add action links
            add_filter( 'plugin_action_links_' . plugin_basename( YITH_WCBK_DIR . '/' . basename( YITH_WCBK_FILE ) ), array( $this, 'action_links' ) );
            add_filter( 'plugin_row_meta', array( $this, 'plugin_row_meta' ), 10, 4 );

            YITH_WCBK_Product_Helper::get_instance();

            // Service Taxonomy Management
            YITH_WCBK_Service_Tax::get_instance();

            // Search Form Management
            YITH_WCBK_Search_Form_Admin::get_instance();

            // class admin for booking obj
            YITH_WCBK_Booking_Admin();

            // Load styles and scripts
            YITH_WCBK_Admin_Assets::get_instance();

            // register plugin to licence/update system
            add_action( 'wp_loaded', array( $this, 'register_plugin_for_activation' ), 99 );
            add_action( 'admin_init', array( $this, 'register_plugin_for_updates' ) );
        }

        /**
         * Action Links
         *
         * add the action links to plugin admin page
         *
         * @param $links | links plugin array
         *
         * @return   mixed Array
         * @since    1.0
         * @author   Leanza Francesco <leanzafrancesco@gmail.com>
         * @author   Francesco Licandro
         * @return mixed
         * @use      plugin_action_links_{$plugin_file_name}
         */
        public function action_links( $links ) {

            $links[] = '<a href="' . admin_url( "admin.php?page={$this->_panel_page}" ) . '">' . __( 'Settings', 'yith-booking-for-woocommerce' ) . '</a>';

            return $links;
        }

        /**
         * plugin_row_meta
         *
         * add the action links to plugin admin page
         *
         * @param $plugin_meta
         * @param $plugin_file
         * @param $plugin_data
         * @param $status
         *
         * @return   Array
         * @since    1.0
         * @use      plugin_row_meta
         */
        public function plugin_row_meta( $plugin_meta, $plugin_file, $plugin_data, $status ) {

            if ( defined( 'YITH_WCBK_INIT' ) && YITH_WCBK_INIT == $plugin_file ) {
                $plugin_meta[] = '<a href="' . $this->doc_url . '" target="_blank">' . __( 'Plugin documentation', 'yith-booking-for-woocommerce' ) .
                                 '</a>';
            }

            return $plugin_meta;
        }

        /**
         * Print the Global availability tab
         */
        public function print_global_availability_tab() {
            include( YITH_WCBK_TEMPLATE_PATH . 'admin/settings-tabs/global-availability.php' );
        }

        /**
         * Print the Global costs tab
         */
        public function print_global_costs_tab() {
            include( YITH_WCBK_TEMPLATE_PATH . 'admin/settings-tabs/global-costs.php' );
        }
        /**
         * Print the Integrations tab
         */
        public function print_integrations_tab() {
            include( YITH_WCBK_TEMPLATE_PATH . 'admin/settings-tabs/integrations.php' );
        }

        /**
         * Add a panel under YITH Plugins tab
         *
         * @return   void
         * @since    1.0
         * @author   Leanza Francesco <leanzafrancesco@gmail.com>
         * @author   Francesco Licandro
         * @use      /Yit_Plugin_Panel class
         * @see      plugin-fw/lib/yit-plugin-panel.php
         */
        public function register_panel() {

            if ( !empty( $this->_panel ) ) {
                return;
            }

            $admin_tabs = array(
                'settings'     => _x( 'Settings', 'Settings tab name', 'yith-booking-for-woocommerce' ),
                'availability' => _x( 'Availability', 'Settings tab name', 'yith-booking-for-woocommerce' ),
                'costs'        => _x( 'Costs', 'Settings tab name', 'yith-booking-for-woocommerce' ),
                'labels'       => _x( 'Labels', 'Settings tab name', 'yith-booking-for-woocommerce' ),
                'integrations' => _x( 'Integrations', 'Settings tab name', 'yith-booking-for-woocommerce' ),
            );

            $admin_tabs = apply_filters( 'yith_wcbk_settings_admin_tabs', $admin_tabs );

            $args = array(
                'create_menu_page' => true,
                'parent_slug'      => '',
                'page_title'       => _x( 'Booking', 'plugin name in admin page title', 'yith-booking-for-woocommerce' ),
                'menu_title'       => _x( 'Booking', 'plugin name in admin WP menu', 'yith-booking-for-woocommerce' ),
                'capability'       => 'manage_options',
                'parent'           => '',
                'parent_page'      => 'yit_plugin_panel',
                'page'             => $this->_panel_page,
                'admin-tabs'       => $admin_tabs,
                'options-path'     => YITH_WCBK_DIR . '/plugin-options',
                'links'            => $this->get_panel_sidebar_links(),
            );

            /* === Fixed: not updated theme  === */
            if ( !class_exists( 'YIT_Plugin_Panel_WooCommerce' ) ) {
                require_once( '../plugin-fw/lib/yit-plugin-panel-wc.php' );
            }

            $this->_panel = new YIT_Plugin_Panel_WooCommerce( $args );
        }

        /**
         * get links for yit panel sidebar
         *
         * @return array
         */
        public function get_panel_sidebar_links() {
            return array(
                array(
                    'url'   => 'http://www.yithemes.com',
                    'title' => __( 'Your Inspiration Themes', 'yith-booking-for-woocommerce' ),
                ),
                array(
                    'url'   => $this->doc_url,
                    'title' => __( 'Plugin Documentation', 'yith-booking-for-woocommerce' ),
                ),
                array(
                    'url'   => 'http://plugins.yithemes.com/yith-woocommerce-booking/',
                    'title' => __( 'Live Demo', 'yith-booking-for-woocommerce' ),
                ),
                array(
                    'url'   => 'https://yithemes.com/my-account/support/dashboard/',
                    'title' => __( 'Support Desk', 'yith-booking-for-woocommerce' ),
                ),
            );
        }

        /**
         * Register plugins for activation tab
         *
         * @return void
         * @since 1.0.0
         */
        public function register_plugin_for_activation() {
            if ( !class_exists( 'YIT_Plugin_Licence' ) ) {
                require_once( YITH_WCBK_DIR . 'plugin-fw/lib/yit-plugin-licence.php' );
            }

            YIT_Plugin_Licence()->register( YITH_WCBK_INIT, YITH_WCBK_SECRET_KEY, YITH_WCBK_SLUG );
        }

        /**
         * Register plugins for update tab
         *
         * @return void
         * @since 1.0.0
         */
        public function register_plugin_for_updates() {
            if ( !class_exists( 'YIT_Upgrade' ) ) {
                require_once( YITH_WCBK_DIR . 'plugin-fw/lib/yit-upgrade.php' );
            }

            YIT_Upgrade()->register( YITH_WCBK_SLUG, YITH_WCBK_INIT );
        }
    }
}

/**
 * Unique access to instance of YITH_WCBK_Admin class
 *
 * @return \YITH_WCBK_Admin
 * @since 1.0.0
 */
function YITH_WCBK_Admin() {

    return YITH_WCBK_Admin::get_instance();
}