<?php
/**
 * AJAX class
 *
 * @author  Yithemes
 * @package YITH Booking for WooCommerce Premium
 * @version 1.0.0
 */


if ( !defined( 'YITH_WCBK' ) ) {
    exit;
} // Exit if accessed directly

if ( !class_exists( 'YITH_WCBK_AJAX' ) ) {
    /**
     * YITH Booking for WooCommerce Premium AJAX
     *
     * @since 1.0.0
     */
    class YITH_WCBK_AJAX {

        /**
         * Single instance of the class
         *
         * @var \YITH_WCBK_AJAX
         * @since 1.0.0
         */
        protected static $_instance;

        /**
         * Returns single instance of the class
         *
         * @return \YITH_WCBK_AJAX
         * @since 1.0.0
         */
        public static function get_instance() {
            if ( is_null( self::$_instance ) ) {
                self::$_instance = new self();
            }

            return self::$_instance;
        }

        /**
         * Constructor
         *
         * @return YITH_WCBK_AJAX
         * @since 1.0.0
         */
        protected function __construct() {
            $ajax_actions = array(
                'json_search_order',
                'json_search_booking_products',
                'get_product_booking_form',
                'mark_booking_status',
                'search_booking_products',
                'search_booking_products_paged'
            );

            foreach ( $ajax_actions as $ajax_action ) {
                add_action( 'wp_ajax_yith_wcbk_' . $ajax_action, array( $this, $ajax_action ) );
                add_action( 'wp_ajax_nopriv_yith_wcbk_' . $ajax_action, array( $this, $ajax_action ) );
            }
        }

        /**
         * @param string $context admin or frontend?
         */
        private function _ajax_start( $context = 'admin' ) {
            !defined( 'YITH_WCBK_DOING_AJAX' ) && define( 'YITH_WCBK_DOING_AJAX', true );
            if ( 'admin' === $context ) {
                !defined( 'YITH_WCBK_DOING_AJAX_ADMIN' ) && define( 'YITH_WCBK_DOING_AJAX_ADMIN', true );
            } elseif ( 'frontend' === $context ) {
                !defined( 'YITH_WCBK_DOING_AJAX_FRONTEND' ) && define( 'YITH_WCBK_DOING_AJAX_FRONTEND', true );
            }
        }

        /**
         * Order Search
         */
        public function json_search_order() {
            $this->_ajax_start();

            global $wpdb;
            ob_start();

            check_ajax_referer( 'search-orders', 'security' );

            $term = wc_clean( stripslashes( $_GET[ 'term' ] ) );

            if ( empty( $term ) ) {
                die();
            }

            $found_orders = array();

            $term = apply_filters( 'yith_wcbk_json_search_order_number', $term );

            $query_orders = $wpdb->get_results( $wpdb->prepare( "
			SELECT ID, post_title FROM {$wpdb->posts} AS posts
			WHERE posts.post_type = 'shop_order'
			AND posts.ID LIKE %s
		", '%' . $term . '%' ) );

            if ( $query_orders ) {
                foreach ( $query_orders as $item ) {
                    $order_number              = apply_filters( 'yith_wcbk_order_number', '#' . $item->ID, $item->ID );
                    $found_orders[ $item->ID ] = $order_number . ' &ndash; ' . esc_html( $item->post_title );
                }
            }

            wp_send_json( $found_orders );
        }

        /**
         * Booking Products Search
         */
        public function json_search_booking_products() {
            $this->_ajax_start();

            ob_start();
            check_ajax_referer( 'search-bookings', 'security' );

            $search_term = isset( $_REQUEST[ 'term' ][ 'term' ] ) ? $_REQUEST[ 'term' ][ 'term' ] : $_REQUEST[ 'term' ];

            $term    = (string) wc_clean( stripslashes( $search_term ) );
            $exclude = array();

            if ( empty( $term ) ) {
                die();
            }

            if ( !empty( $_REQUEST[ 'exclude' ] ) ) {
                $exclude = array_map( 'intval', explode( ',', $_REQUEST[ 'exclude' ] ) );
            }


            $found_products = array();

            if ( $booking_term = get_term_by( 'slug', 'booking', 'product_type' ) ) {

                $posts_in = array_unique( (array) get_objects_in_term( $booking_term->term_id, 'product_type' ) );

                if ( sizeof( $posts_in ) > 0 ) {

                    $args = array(
                        'post_type'        => 'product',
                        'post_status'      => 'publish',
                        'numberposts'      => -1,
                        'orderby'          => 'title',
                        'order'            => 'asc',
                        'post_parent'      => 0,
                        'suppress_filters' => 0,
                        'include'          => $posts_in,
                        's'                => $term,
                        'fields'           => 'ids',
                        'exclude'          => $exclude,
                    );

                    $posts = get_posts( $args );

                    if ( !empty( $posts ) ) {
                        foreach ( $posts as $post ) {
                            $product = wc_get_product( $post );

                            if ( !current_user_can( 'read_product', $post ) ) {
                                continue;
                            }

                            $found_products[ $post ] = rawurldecode( $product->get_formatted_name() );
                        }
                    }
                }
            }

            $found_products = apply_filters( 'yith_wcbk_json_search_found_booking_products', $found_products );

            wp_send_json( $found_products );
        }

        /**
         * Get the product booking form
         */
        public function get_product_booking_form() {
            $this->_ajax_start();

            if ( isset( $_POST[ 'product_id' ] ) ) {
                $product = wc_get_product( absint( $_POST[ 'product_id' ] ) );
                do_action( 'yith_wcbk_booking_form', $product, true );
            }
            die();
        }

        /**
         * Mark an order with a status.
         */
        public function mark_booking_status() {
            $this->_ajax_start();

            if ( current_user_can( 'edit_' . YITH_WCBK_Post_Types::$booking . 's' ) && check_admin_referer( 'yith-wcbk-mark-booking-status' ) ) {
                $status     = sanitize_text_field( $_GET[ 'status' ] );
                $booking_id = absint( $_GET[ 'booking_id' ] );

                if ( yith_wcbk_is_a_booking_status( $status ) && $booking_id ) {
                    $booking = yith_get_booking( $booking_id );
                    $booking->update_status( $status );
                }
            }

            wp_safe_redirect( wp_get_referer() ? wp_get_referer() : admin_url( 'edit.php?post_type=' . YITH_WCBK_Post_Types::$booking ) );
            die();
        }

        public function search_booking_products() {
            $this->_ajax_start( 'frontend' );

            check_ajax_referer( 'search-booking-products', 'security' );

            if ( isset( $_REQUEST[ 'yith-wcbk-booking-search' ] ) && $_REQUEST[ 'yith-wcbk-booking-search' ] === 'search-bookings' ) {

                $this->set_in_search_form_const();

                $from         = isset( $_REQUEST[ 'from' ] ) ? $_REQUEST[ 'from' ] : '';
                $to           = isset( $_REQUEST[ 'to' ] ) ? $_REQUEST[ 'to' ] : '';
                $persons      = isset( $_REQUEST[ 'persons' ] ) ? $_REQUEST[ 'persons' ] : 1;
                $person_types = isset( $_REQUEST[ 'person_types' ] ) ? $_REQUEST[ 'person_types' ] : array();
                $services     = isset( $_REQUEST[ 'services' ] ) ? $_REQUEST[ 'services' ] : array();

                if ( !!$person_types && is_array( $person_types ) ) {
                    $persons = array_sum( array_values( $person_types ) );
                }

                $product_ids = YITH_WCBK()->search_form_helper->search_booking_products( $_REQUEST );

                if ( !$product_ids ) {
                    $no_bookings_available_text = __( 'No bookings available for this search', 'yith-booking-for-woocommerce' );
                    echo apply_filters( 'yith_wcbk_search_booking_products_no_bookings_available_text', $no_bookings_available_text );
                    do_action( 'yith_wcbk_search_booking_products_no_bookings_available_after' );
                    die();
                }

                $current_page = 1;

                $args     = array(
                    'post_type'           => 'product',
                    'ignore_sticky_posts' => 1,
                    'no_found_rows'       => 1,
                    'posts_per_page'      => apply_filters( 'yith_wcbk_ajax_search_booking_products_posts_per_page', 12 ),
                    'paged'               => $current_page,
                    'post__in'            => $product_ids,
                    'orderby'             => 'post__in',
                    'meta_query'          => WC()->query->get_meta_query(),
                );
                $args     = apply_filters( 'yith_wcbk_ajax_search_booking_products_query_args', $args, $product_ids );
                $products = new WP_Query( $args );

                $booking_request = array(
                    'from'             => $from,
                    'to'               => $to,
                    'persons'          => $persons,
                    'person_types'     => $person_types,
                    'booking_services' => $services,
                );

                wc_get_template( 'booking/search-form/booking-search-form-results.php', compact( 'booking_request', 'products', 'product_ids', 'current_page' ), '', YITH_WCBK_TEMPLATE_PATH );
            }

            die();
        }


        public function search_booking_products_paged() {
            $this->_ajax_start( 'frontend' );
            
            if ( !empty( $_REQUEST[ 'product_ids' ] ) && !empty( $_REQUEST[ 'booking_request' ] ) && !empty( $_REQUEST[ 'page' ] ) ) {
                $this->set_in_search_form_const();

                $product_ids     = $_REQUEST[ 'product_ids' ];
                $booking_request = $_REQUEST[ 'booking_request' ];
                $current_page    = absint( $_REQUEST[ 'page' ] );

                $args = array(
                    'post_type'           => 'product',
                    'ignore_sticky_posts' => 1,
                    'no_found_rows'       => 1,
                    'posts_per_page'      => apply_filters( 'yith_wcbk_ajax_search_booking_products_posts_per_page', 12 ),
                    'paged'               => $current_page,
                    'post__in'            => $product_ids,
                    'meta_query'          => WC()->query->get_meta_query(),
                );
                $args = apply_filters( 'yith_wcbk_ajax_search_booking_products_query_args', $args, $product_ids );

                $products = new WP_Query( $args );

                wc_get_template( 'booking/search-form/booking-search-form-results-list.php', compact( 'products', 'booking_request' ), '', YITH_WCBK_TEMPLATE_PATH );
            }

            die();
        }

        public function set_in_search_form_const() {
            if ( !defined( 'YITH_WCBK_IS_IN_AJAX_SEARCH_FORM_RESULTS' ) ) {
                define( 'YITH_WCBK_IS_IN_AJAX_SEARCH_FORM_RESULTS', true );
            }
        }


    }
}