<?php
/**
 * Product Helper class
 *
 * @author  Yithemes
 * @package YITH Booking for WooCommerce Premium
 * @version 1.0.0
 */


if ( !defined( 'YITH_WCBK' ) ) {
    exit;
} // Exit if accessed directly

if ( !class_exists( 'YITH_WCBK_Printer' ) ) {

    /**
     * YITH Booking for WooCommerce Premium Printer
     *
     * @since 1.0.0
     */
    class YITH_WCBK_Printer {
        /**
         * Single instance of the class
         *
         * @var \YITH_WCBK_Product_Helper
         * @since 1.0.0
         */
        protected static $_instance;

        /**
         * Returns single instance of the class
         *
         * @return \YITH_WCBK_Product_Helper
         * @since 1.0.0
         */
        public static function get_instance() {
            if ( is_null( self::$_instance ) ) {
                self::$_instance = new self();
            }

            return self::$_instance;
        }

        /**
         * Constructor
         *
         */
        public function __construct() {

        }

        public function print_fields( $args = array() ) {
            foreach ( $args as $field_args ) {
                $this->print_field( $field_args );
            }
        }

        public function print_field( $args = array() ) {
            $default_args = array(
                'type'              => '',
                'id'                => '',
                'name'              => '',
                'value'             => '',
                'class'             => '',
                'custom_attributes' => '',
                'for'               => '',
                'options'           => array(),
                'data'              => array(),
                'title'             => '',
                'fields'            => array(),
                'help_tip'          => '',
                'desc'              => '',
                'section_html_tag'  => 'p'
            );
            $args         = apply_filters( 'yith_wcbk_printer_print_field_args', $args );
            $args         = wp_parse_args( $args, $default_args );

            $type     = $args[ 'type' ];
            $title    = $args[ 'title' ];
            $help_tip = $args[ 'help_tip' ];
            $desc     = $args[ 'desc' ];

            if ( !empty( $title ) && $type !== 'checkbox' ) {
                $this->print_field( array(
                                        'type'  => 'label',
                                        'value' => $title,
                                        'for'   => $args[ 'id' ]
                                    ) );
            }

            switch ( $type ) {
                case 'section':
                    $fields = $args[ 'fields' ];
                    unset( $args[ 'fields' ] );

                    $args[ 'type' ] = 'section-start';
                    $this->print_field( $args );

                    if ( !empty( $fields ) ) {
                        foreach ( $fields as $field_args ) {
                            $this->print_field( $field_args );
                        }
                    } elseif ( !empty( $args[ 'value' ] ) ) {
                        $this->print_field( array(
                                                'type'  => 'html',
                                                'value' => $args[ 'value' ],
                                            ) );
                    }

                    $args[ 'type' ] = 'section-end';
                    $this->print_field( $args );
                    break;
                default:
                    if ( file_exists( YITH_WCBK_TEMPLATE_PATH . 'printer/types/' . $type . '.php' ) ) {
                        wc_get_template( 'printer/types/' . $type . '.php', $args, '', YITH_WCBK_TEMPLATE_PATH );
                    }
                    break;
            }

            if ( !empty( $title ) && $type === 'checkbox' ) {
                $this->print_field( array(
                                        'type'  => 'label',
                                        'value' => $title,
                                        'for'   => $args[ 'id' ]
                                    ) );
            }

            if ( !empty( $help_tip ) ) {
                $this->print_field( array(
                                        'type'  => 'help-tip',
                                        'value' => $help_tip,
                                    ) );
            } elseif ( !empty( $desc ) ) {
                $this->print_field( array(
                                        'type'             => 'section',
                                        'value'            => $desc,
                                        'class'            => 'description',
                                        'section_html_tag' => 'span'
                                    ) );
            }
        }
    }
}

/**
 * Unique access to instance of YITH_WCBK_Printer class
 *
 * @return \YITH_WCBK_Printer
 * @since 1.0.0
 */
function YITH_WCBK_Printer() {
    return YITH_WCBK_Printer::get_instance();
}
