<?php
/**
 * Search Form Frontend class
 *
 * @author  Yithemes
 * @package YITH Booking for WooCommerce Premium
 * @version 1.0.0
 */


if ( !defined( 'YITH_WCBK' ) ) {
    exit;
} // Exit if accessed directly

if ( !class_exists( 'YITH_WCBK_Search_Form_Frontend' ) ) {
    /**
     * YITH Booking for WooCommerce Premium Search Form Frontend
     *
     * @since 1.0.0
     */
    class YITH_WCBK_Search_Form_Frontend {
        /**
         * Single instance of the class
         *
         * @var \YITH_WCBK_Search_Form_Frontend
         * @since 1.0.0
         */
        protected static $_instance;

        /**
         * Returns single instance of the class
         *
         * @return \YITH_WCBK_Search_Form_Frontend
         * @since 1.0.0
         */
        public static function get_instance() {
            if ( is_null( self::$_instance ) ) {
                self::$_instance = new self();
            }

            return self::$_instance;
        }

        /**
         * Constructor
         *
         * @since  1.0.0
         * @author Leanza Francesco <leanzafrancesco@gmail.com>
         */
        public function __construct() {
            add_action( 'yith_wcbk_booking_search_form_print_field', array( $this, 'print_field' ), 10, 3 );

            add_action( 'pre_get_posts', array( $this, 'filter_search_results_in_shop' ) );
        }

        /**
         * filter search results in shop
         *
         * @param WP_Query $query
         */
        public function filter_search_results_in_shop( $query ) {
            if ( $query->is_main_query() && is_shop() && isset( $_REQUEST[ 'yith-wcbk-booking-search' ] ) && $_REQUEST[ 'yith-wcbk-booking-search' ] === 'search-bookings' ) {
                $product_ids = YITH_WCBK()->search_form_helper->search_booking_products( $_REQUEST );

                if ( !$product_ids )
                    $product_ids = array( 0 );

                $query->set( 'post__in', $product_ids );
            }
        }

        /**
         * @param                       $field_name
         * @param                       $field_data
         * @param YITH_WCBK_Search_Form $search_form
         */
        public function print_field( $field_name, $field_data, $search_form ) {
            $template = $field_name;

            if ( !empty( $field_data[ 'type' ] ) ) {
                $template .= '-' . $field_data[ 'type' ];
            }

            $template .= '.php';

            $args = array(
                'field_name'  => $field_name,
                'field_data'  => $field_data,
                'search_form' => $search_form,
            );

            wc_get_template( 'booking/search-form/fields/' . $template, $args, '', YITH_WCBK_TEMPLATE_PATH );
        }
    }
}