<?php
/**
 * Search Form class
 *
 * @author  Yithemes
 * @package YITH Booking for WooCommerce Premium
 * @version 1.0.0
 */


if ( !defined( 'YITH_WCBK' ) ) {
    exit;
} // Exit if accessed directly

if ( !class_exists( 'YITH_WCBK_Search_Form' ) ) {
    /**
     * YITH Booking for WooCommerce Premium Search Form
     *
     * @since 1.0.0
     */
    class YITH_WCBK_Search_Form {

        /**
         * id of the cpt Search Form
         *
         * @var int
         */
        public $id;

        /**
         * number of the instance
         *
         * @var int
         */
        public static $instance_number = 0;

        /**
         * the current number of the instance
         *
         * @var int
         */
        private $_current_instance_number;


        /**
         * @var array
         */
        private $_data = array();

        /**
         * the post object
         *
         * @var WP_Post
         */
        private $_post;

        /**
         * Constructor
         *
         * @since  1.0.0
         * @author Leanza Francesco <leanzafrancesco@gmail.com>
         *
         * @param int $id
         */
        public function __construct( $id ) {
            $this->id = absint( $id );

            self::$instance_number++;
            $this->_current_instance_number = self::$instance_number;

            $this->_post = get_post( $this->id );
        }

        /**
         * return the current instance number
         *
         * @return int
         */
        public function get_current_instance_number() {
            return $this->_current_instance_number;
        }

        /**
         * return the unique id of the search form
         * id-current_instance_number
         *
         * @return string
         */
        public function get_unique_id() {
            return $this->id . '-' . $this->get_current_instance_number();
        }

        /**
         * @return array|null|WP_Post
         */
        public function get_post_data() {
            return $this->_post;
        }

        /**
         * get the options of the form
         *
         * @return array
         */
        public function get_options() {
            if ( !array_key_exists( 'options', $this->_data ) ) {
                $this->_data[ 'options' ] = array(
                    'show-results' => ( $meta = get_post_meta( $this->id, '_show-results', true ) ) ? $meta : 'popup',
                );
            }

            return $this->_data[ 'options' ];
        }

        /**
         * get the style setting of the form
         *
         * @return array
         */
        public function get_styles() {
            if ( !array_key_exists( 'styles', $this->_data ) ) {
                $this->_data[ 'styles' ] = array(
                    'style'                   => ( $meta = get_post_meta( $this->id, '_style', true ) ) ? $meta : 'default',
                    'background-color'        => ( $meta = get_post_meta( $this->id, '_background-color', true ) ) ? $meta : '#ffffff',
                    'text-color'              => ( $meta = get_post_meta( $this->id, '_text-color', true ) ) ? $meta : '#333333',
                    'search-background-color' => ( $meta = get_post_meta( $this->id, '_search-background-color', true ) ) ? $meta : '#000000',
                    'search-text-color'       => ( $meta = get_post_meta( $this->id, '_search-text-color', true ) ) ? $meta : '#ffffff',
                    'search-hover-color'      => ( $meta = get_post_meta( $this->id, '_search-hover-color', true ) ) ? $meta : '#2470ff',
                );
            }

            return $this->_data[ 'styles' ];
        }

        /**
         * Get fields
         *
         * @author Leanza Francesco <leanzafrancesco@gmail.com>
         * @return array
         */
        public function get_fields() {
            if ( !array_key_exists( 'fields', $this->_data ) ) {
                $default_fields = array(
                    'location'   => array(
                        'enabled' => 'yes',
                    ),
                    'categories' => array(
                        'enabled' => 'no',
                    ),
                    'date'       => array(
                        'enabled' => 'yes',
                        'type'    => 'day',
                    ),
                    'persons'    => array(
                        'enabled' => 'yes',
                        'type'    => 'persons',
                    ),
                    'services'   => array(
                        'enabled' => 'yes',
                    ),
                );

                $fields = get_post_meta( $this->id, '_yith_wcbk_admin_search_form_fields', true );
                $fields = !!$fields ? wp_parse_args( $fields, $default_fields ) : $default_fields;

                $this->_data[ 'fields' ] = $fields;
            }

            return $this->_data[ 'fields' ];
        }


        /**
         * return true if the search form is valid
         *
         * @return bool
         */
        public function is_valid() {
            return !empty( $this->id ) && !empty( $this->_post );
        }

        /**
         * Print the search form
         */
        public function output() {
            if ( !$this->is_valid() )
                return;

            $args = array(
                'search_form' => $this
            );
            wc_get_template( 'booking/search-form/booking-search-form.php', $args, '', YITH_WCBK_TEMPLATE_PATH );
        }
    }
}