<?php
if ( !defined( 'ABSPATH' ) ) {
    exit;
} // Exit if accessed directly

/**
 * WPML services Class
 *
 * @class   YITH_WCBK_Wpml_Services
 * @package Yithemes
 * @since   1.0.3
 * @author  Yithemes
 *
 */
class YITH_WCBK_Wpml_Services {
    /** @var YITH_WCBK_Wpml_Search_Forms */
    private static $_instance;

    /** @var YITH_WCBK_Wpml_Integration */
    public $wpml_integration;

    /**
     * Returns single instance of the class
     *
     * @param YITH_WCBK_Wpml_Integration $wpml_integration
     *
     * @return YITH_WCBK_Wpml_Search_Forms
     */
    public static function get_instance( $wpml_integration ) {
        return !is_null( self::$_instance ) ? self::$_instance : self::$_instance = new static( $wpml_integration );
    }

    /**
     * Constructor
     *
     * @access private
     *
     * @param YITH_WCBK_Wpml_Integration $wpml_integration
     */
    private function __construct( $wpml_integration ) {
        $this->wpml_integration = $wpml_integration;

        // translate the service names
        add_filter( 'yith_wcbk_get_service_name', array( $this, 'translate_service_name' ), 10, 2 );

        // Display extra fields for taxonomy
        add_action( YITH_WCBK_Post_Types::$service_tax . '_add_form_fields', array( $this, 'add_taxonomy_fields' ), 1, 1 );
        add_action( YITH_WCBK_Post_Types::$service_tax . '_edit_form_fields', array( $this, 'edit_taxonomy_fields' ), 1, 1 );


        // Display languages in service table
        add_filter( 'manage_edit-' . YITH_WCBK_Post_Types::$service_tax . '_columns', array( $this, 'get_columns' ) );
        add_filter( 'manage_' . YITH_WCBK_Post_Types::$service_tax . '_custom_column', array( $this, 'custom_columns' ), 10, 3 );

        // $flags_column .= '<img src="' . $this->sitepress->get_flag_url( $language_data['code'] ). '" width="18" height="12" alt="' . $language_data['display_name'] . '" title="' . $language_data['display_name'] . '" style="margin:2px" />';
    }

    /**
     * Add fields to Service taxonomy [Add New Service Screen]
     *
     * @param  string $taxonomy Current taxonomy name
     *
     * @author Leanza Francesco <leanzafrancesco@gmail.com>
     * @return void
     */
    public function add_taxonomy_fields( $taxonomy ) {
        global $sitepress;
        $active_languages = $sitepress->get_active_languages();
        $languages        = $active_languages;

        if ( isset( $languages[ $this->wpml_integration->default_language ] ) ) {
            unset( $languages[ $this->wpml_integration->default_language ] );
        }

        include( YITH_WCBK_TEMPLATE_PATH . 'admin/taxonomies/service/wpml/add-service.php' );
    }

    /**
     * Add WPML Languages column
     *
     *
     * @param string $columns the column
     *
     * @return array The columns list
     * @use   manage_{YITH_WCBK_Post_Types::$service_tax}_columns filter
     * @since 1.0.0
     */
    public function get_columns( $columns ) {
        $wpml_languages_title = __( 'WPML Languages', 'yith-booking-for-woocommerce' );
        $to_add               = array(
            'service_wpml_languages' => "<span class='yith-wcbk-wpml-languages-head tips' data-tip='{$wpml_languages_title}'>$wpml_languages_title</span>"
        );

        return array_merge( $columns, $to_add );
    }

    /**
     * Display WPML flags
     *
     *
     * @param string $custom_column Filter value
     * @param string $column_name Column name
     * @param int    $term_id The term id
     *
     * @internal param \The $columns columns
     *
     * @return array The columns list
     * @use      manage_{YITH_WCBK_Post_Types::$service_tax}_custom_column filter
     * @since    1.0.0
     */
    public function custom_columns( $custom_column, $column_name, $term_id ) {
        $service = yith_get_booking_service( $term_id );
        switch ( $column_name ) {
            case 'service_wpml_languages':
                global $sitepress;
                $active_languages = $sitepress->get_active_languages();
                $languages        = $active_languages;

                if ( isset( $languages[ $this->wpml_integration->default_language ] ) ) {
                    unset( $languages[ $this->wpml_integration->default_language ] );
                }
                foreach ( $languages as $language_code => $language_data ) {
                    if ( !empty( $service->wpml_translated_name[ $language_code ] ) ) {
                        $service_translated_name = $service->wpml_translated_name[ $language_code ];
                        $flag_url                = $this->wpml_integration->sitepress->get_flag_url( $language_code );
                        $language_name           = $language_data[ 'display_name' ];
                        $info                    = "$service_translated_name ($language_name)";
                        $flag                    = "<img class='tips' src='$flag_url' width='18' height='12' alt='$language_name' data-tip='$info' style='margin:2px' />";
                        echo $flag;
                    }
                }
                break;
        }
    }

    /**
     * Edit fields to service taxonomy
     *
     * @param  WP_Term $service_term Current service information
     *
     * @author Leanza Francesco <leanzafrancesco@gmail.com>
     * @return void
     */
    public function edit_taxonomy_fields( $service_term ) {
        global $sitepress;
        $active_languages = $sitepress->get_active_languages();
        $languages        = $active_languages;

        if ( isset( $languages[ $this->wpml_integration->default_language ] ) ) {
            unset( $languages[ $this->wpml_integration->default_language ] );
        }

        $service_id = $service_term->term_id;
        $service    = yith_get_booking_service( $service_id, $service_term );

        include( YITH_WCBK_TEMPLATE_PATH . 'admin/taxonomies/service/wpml/edit-service.php' );
    }

    /**
     * @param string            $name
     * @param YITH_WCBK_Service $service
     *
     * @return string
     */
    public function translate_service_name( $name, $service ) {
        $language_code = $this->wpml_integration->current_language;

        return !empty( $service->wpml_translated_name[ $language_code ] ) ? $service->wpml_translated_name[ $language_code ] : $name;
    }
}