<?php
/**
 * Booking form persons
 *
 * @author        Leanza Francesco <leanzafrancesco@gmail.com>
 *
 * @var WC_Product_Booking $product
 */

if ( !defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

if ( !$product->has_persons() )
    return;

?>
<div class="yith-wcbk-form-section-persons-wrapper">
    <?php
    if ( !$product->has_person_types() ) {
        $min = absint( $product->get_booking_prop( 'min_persons' ) );
        $min = max( 1, $min );
        $max = absint( $product->get_booking_prop( 'max_persons' ) );

        $custom_attributes = "step='1' min='{$min}'";
        $custom_attributes .= $max > 0 ? " max='{$max}'" : '';

        YITH_WCBK_Printer()->print_field( array(
                                              'type'             => 'section',
                                              'section_html_tag' => 'div',
                                              'class'            => 'yith-wcbk-form-section yith-wcbk-form-section-persons',
                                              'fields'           => array(
                                                  array(
                                                      'title'             => __( 'People', 'yith-booking-for-woocommerce' ),
                                                      'type'              => 'number',
                                                      'id'                => 'yith-wcbk-booking-persons',
                                                      'name'              => 'persons',
                                                      'custom_attributes' => $custom_attributes,
                                                      'value'             => $min,
                                                      'class'             => 'yith-wcbk-booking-persons yith-wcbk-number-minifield',
                                                  ),
                                              ),
                                          ) );
    } else {
        foreach ( $product->get_person_types() as $person_type ) {
            /**
             * @var bool $enabled
             * @var int  $id
             * @var int  $min
             * @var int  $max
             * @var int  $base_cost
             * @var int  $block_cost
             */
            extract( $person_type );

            $min = max( 0, $min );

            if ( !$enabled )
                continue;

            $custom_attributes = "step='1' min='{$min}'";
            $custom_attributes .= $max > 0 ? " max='{$max}'" : '';

            $person_type_print_args = array(
                'type'             => 'section',
                'section_html_tag' => 'div',
                'class'            => 'yith-wcbk-form-section yith-wcbk-form-section-person-types',
                'fields'           => array(
                    array(
                        'title'             => YITH_WCBK()->person_type_helper->get_person_type_title( $id ),
                        'type'              => 'number',
                        'id'                => 'yith-wcbk-booking-persons-type-' . $id,
                        'name'              => "person_types[$id]",
                        'data'              => array(
                            'person-type-id' => $id,
                        ),
                        'custom_attributes' => $custom_attributes,
                        'value'             => $min,
                        'class'             => 'yith-wcbk-booking-person-types yith-wcbk-number-minifield',
                    ),
                ),
            );


            YITH_WCBK_Printer()->print_field( $person_type_print_args );
        }
    }
    ?>
</div>

