<?php
/**
 * Booking product add to cart
 *
 * @author        Leanza Francesco <leanzafrancesco@gmail.com>
 *
 * @var WC_Product_Booking $product
 */

if ( !defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

global $product;

do_action( 'yith_wcbk_before_booking_form' );

if ( !$product->is_purchasable() ) {
    return;
}

if ( YITH_WCBK()->settings->show_booking_form_to_logged_users_only() && !is_user_logged_in() ) {
    echo apply_filters( 'yith_wcbk_show_booking_form_to_logged_users_only_non_logged_text', __( 'You must be logged in to book this product!', 'yith-booking-for-woocommerce' ) );

    return;
}

if ( !apply_filters( 'yith_wcbk_show_booking_form', true ) )
    return;

?>
<?php do_action( 'woocommerce_before_add_to_cart_form' ); ?>

<form class="cart" method="post" enctype='multipart/form-data'>
    <?php do_action( 'woocommerce_before_booking_form' ); ?>

    <?php
    $action   = !$product->is_requested_confirmation() ? 'add-to-cart' : 'booking-request-confirmation';
    $checkin  = $product->get_booking_prop( 'checkin' );
    $checkout = $product->get_booking_prop( 'checkout' );
    ?>
    <?php if ( !!$checkin || !!$checkout ): ?>

        <table class="yith-booking-meta">
            <tr>

                <?php if ( !!$checkin ): ?>
                    <td class="yith-booking-checkin"><?php echo sprintf( __( '%s: %s', 'yith-booking-for-woocommerce' ), yith_wcbk_get_label( 'check-in' ), $checkin ) ?></td>
                <?php endif; ?>

                <?php if ( !!$checkout ): ?>
                    <td class="yith-booking-checkout"><?php echo sprintf( __( '%s: %s', 'yith-booking-for-woocommerce' ), yith_wcbk_get_label( 'check-out' ), $checkout ) ?></td>
                <?php endif; ?>
            </tr>
        </table>

    <?php endif; ?>


    <input type="hidden" name="<?php echo $action ?>" value="<?php echo esc_attr( $product->get_id() ); ?>"/>

    <?php
    //$form = new YITH_WCBK_Product_Form( $product );
    //$form->output();

    /**
     * yith_wcbk_booking_form_start hook.
     *
     * @hooked yith_wcbk_booking_form_start - 10
     */
    do_action( 'yith_wcbk_booking_form_start', $product );

    /**
     * yith_wcbk_booking_form_start hook.
     *
     * @hooked yith_wcbk_booking_form_start - 10
     */
    do_action( 'yith_wcbk_booking_form_persons', $product );

    /**
     * yith_wcbk_booking_form_start hook.
     *
     * @hooked yith_wcbk_booking_form_start - 10
     */
    do_action( 'yith_wcbk_booking_form_dates', $product );

    /**
     * yith_wcbk_booking_form_start hook.
     *
     * @hooked yith_wcbk_booking_form_start - 10
     */
    do_action( 'yith_wcbk_booking_form_services', $product );

    /**
     * yith_wcbk_booking_form_start hook.
     *
     * @hooked yith_wcbk_booking_form_start - 10
     */
    do_action( 'yith_wcbk_booking_form_message', $product );

    /**
     * yith_wcbk_booking_form_start hook.
     *
     * @hooked yith_wcbk_booking_form_start - 10
     */
    do_action( 'yith_wcbk_booking_form_end', $product );
    ?>

    <?php do_action( 'woocommerce_before_add_to_cart_button' ); ?>

    <button type="submit" class="single_add_to_cart_button button alt"
            disabled><?php echo esc_html( $product->single_add_to_cart_text() ); ?></button>

    <?php do_action( 'woocommerce_after_add_to_cart_button' ); ?>
</form>

<?php do_action( 'woocommerce_after_add_to_cart_form' ); ?>

